# カレントドライブを移動
cd "$1"

# HTML 形式のファイルパスを取得し配列に格納する
HTML_PATH=($(find ./ -name "*.html"))

# カウンタ
COUNT=0

# ディレクトリがなければ、生成
mkdir -p md

# 配列でループ
for HTML_FILE in ${HTML_PATH[@]}; do
  # 拡張子を md に変換する
  MD_FILE=$(echo $HTML_FILE | sed -e "s|\.html|.md|" -e "s|^\.\/|./md|")
  MD_CACHE_FILE=$(echo $HTML_FILE | sed -e "s|\.html|.md.tmp|" -e "s|^\.\/|./md|")
  MD_CACHE_FILE2=$(echo $HTML_FILE | sed -e "s|\.html|.v2.md.tmp|" -e "s|^\.\/|./md|")
  HTML_FILE=$(echo $HTML_FILE | sed -e "s|^\.\/\/|./|")

  # ファイルの更新日時を比較する
  if [ $HTML_FILE -nt $MD_FILE ]; then
    # HTML が新しければ Pandoc で Markdown 生成
    /usr/local/bin/pandoc -f html $HTML_FILE -t markdown-multiline_tables-simple_tables-yaml_metadata_block-pandoc_title_block-header_attributes+hard_line_breaks --wrap=none --atx-headers --reference-links --tab-stop=2  -o $MD_CACHE_FILE

    # 1行目の大見出しの書式を変更、2行目に文字列を追加
    sed -i.bak -e "1s/^#\ //g" -e "2s/^/==================【改行】/g" $MD_CACHE_FILE
    # 2行目の文字列を改行コードに置換して行を追加
    cat $MD_CACHE_FILE | perl -pe 's/【改行】/\n/' > $MD_CACHE_FILE2

    # Markdown 内の code ブロックの言語指定部分の文字列を置換（.sourceCode と言語名のクラスがある場合）
    cat $MD_CACHE_FILE2 | perl -pe 's/ {.sourceCode .(.+)}$/$1/g' > $MD_CACHE_FILE
    # Markdown 内の code ブロックの言語指定部分の文字列を置換（言語名のクラスだけがある場合）
    cat $MD_CACHE_FILE | perl -pe 's/ {.(.+)}$/$1/g' > $MD_CACHE_FILE2
    # Markdown 内の code ブロックの言語指定部分の文字列を置換（言語名指定がない場合）
    cat $MD_CACHE_FILE2 | perl -pe 's/```sourceCode$/```/g' > $MD_FILE

    # 変換したファイル数をカウント
    COUNT=$(( COUNT + 1 ))
  fi
done

# 拡張子 .md.tmp または .md.tmp.bak の不要なファイルを削除
find ./md/ -name "*.md.tmp" -o -name '*.md.tmp.bak' | xargs rm

# 結果表示
echo $COUNT "files converted."
